summaryrefslogtreecommitdiffstats
path: root/kdat/LoggerWidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/LoggerWidget.h')
-rw-r--r--kdat/LoggerWidget.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kdat/LoggerWidget.h b/kdat/LoggerWidget.h
index fed21c0..d649e65 100644
--- a/kdat/LoggerWidget.h
+++ b/kdat/LoggerWidget.h
@@ -28,16 +28,17 @@ class TQMultiLineEdit;
*/
class LoggerWidget : public TQWidget {
Q_OBJECT
+ TQ_OBJECT
TQMultiLineEdit* _mle;
public:
/**
* Create a titled logging widget
*
* @param title The title text displayed above the logging window.
* @param parent The parent widget.
* @param name The name of this widget.
*/
- LoggerWidget( const TQString & title, TQWidget* parent = 0, const char* name = 0 );
+ LoggerWidget( const TQString & title, TQWidget* tqparent = 0, const char* name = 0 );
/**
* Destroy the logging widget.
@@ -28,16 +28,17 @@ class TQMultiLineEdit;
*
* @param title The title text displayed above the logging window.
- * @param parent The parent widget.
+ * @param tqparent The tqparent widget.
* @param name The name of this widget.
*/